# frozen_string_literal: true

module CommonModels
    module Services
        # Abstract data service that every component that has a controller role in a
        # control loop should provide
        data_service_type "Controller"
    end
end
